
{% for wrapped in object_list %}
  <!-- result is a ModelWithLogEntry wrapper -->
  <tr>
    <!--counter-->
    <td>{{ page_obj.start_index|add:forloop.counter0 }}</td>
    <!--buttons-->

      {% include 'edc_lab_dashboard/listboard/pack/columns.html' %}

  </tr>

{% endfor %}
